@@ -23,7 +23,7 @@ pub struct InitialDisplayData {
     pub colors_on: bool,
     pub by_filecount: bool,
     pub is_screen_reader: bool,
-    pub iso: bool,
+    pub output_format: String,
     pub bars_on_right: bool,
 }
 
@@ -142,7 +142,7 @@ pub fn draw_it(
         let max_size = biggest.size;
         max_size.separate_with_commas().chars().count()
     } else {
-        find_biggest_size_str(root_node, idd.iso)
+        find_biggest_size_str(root_node, &idd.output_format)
     };
 
     assert!(
@@ -190,10 +190,12 @@ pub fn draw_it(
     }
 }
 
-fn find_biggest_size_str(node: &DisplayNode, iso: bool) -> usize {
-    let mut mx = human_readable_number(node.size, iso).chars().count();
+fn find_biggest_size_str(node: &DisplayNode, output_format: &str) -> usize {
+    let mut mx = human_readable_number(node.size, output_format)
+        .chars()
+        .count();
     for n in node.children.iter() {
-        mx = max(mx, find_biggest_size_str(n, iso));
+        mx = max(mx, find_biggest_size_str(n, output_format));
     }
     mx
 }
@@ -375,7 +377,7 @@ fn get_pretty_size(node: &DisplayNode, is_biggest: bool, display_data: &DisplayD
     let output = if display_data.initial.by_filecount {
         node.size.separate_with_commas()
     } else {
-        human_readable_number(node.size, display_data.initial.iso)
+        human_readable_number(node.size, &display_data.initial.output_format)
     };
     let spaces_to_add = display_data.num_chars_needed_on_left_most - output.chars().count();
     let output = " ".repeat(spaces_to_add) + output.as_str();
@@ -407,19 +409,48 @@ fn get_pretty_name(
     }
 }
 
-pub fn human_readable_number(size: u64, iso: bool) -> String {
+// If we are working with SI units or not
+pub fn get_type_of_thousand(output_str: &str) -> u64 {
+    let is_si = output_str.contains('i'); // si, KiB, MiB, etc
+    if is_si {
+        1000
+    } else {
+        1024
+    }
+}
+
+pub fn get_number_format(output_str: &str) -> Option<(u64, char)> {
+    if output_str.starts_with('b') {
+        return Some((1, 'B'));
+    }
     for (i, u) in UNITS.iter().enumerate() {
-        let num: u64 = if iso { 1000 } else { 1024 };
-        let marker = num.pow((UNITS.len() - i) as u32);
-        if size >= marker {
-            if size / marker < 10 {
-                return format!("{:.1}{}", (size as f32 / marker as f32), u);
-            } else {
-                return format!("{}{}", (size / marker), u);
+        if output_str.starts_with((*u).to_ascii_lowercase()) {
+            let marker = get_type_of_thousand(output_str).pow((UNITS.len() - i) as u32);
+            return Some((marker, *u));
+        }
+    }
+    None
+}
+
+pub fn human_readable_number(size: u64, output_str: &str) -> String {
+    match get_number_format(output_str) {
+        Some((x, u)) => {
+            format!("{}{}", (size / x), u)
+        }
+        None => {
+            for (i, u) in UNITS.iter().enumerate() {
+                let marker = get_type_of_thousand(output_str).pow((UNITS.len() - i) as u32);
+                if size >= marker {
+                    if size / marker < 10 {
+                        return format!("{:.1}{}", (size as f32 / marker as f32), u);
+                    } else {
+                        return format!("{}{}", (size / marker), u);
+                    }
+                }
             }
+            format!("{size}B")
         }
     }
-    format!("{size}B")
 }
 
 mod tests {
@@ -436,7 +467,7 @@ mod tests {
             colors_on: false,
             by_filecount: false,
             is_screen_reader: false,
-            iso: false,
+            output_format: "".into(),
             bars_on_right: false,
         };
         DisplayData {
@@ -503,22 +534,37 @@ mod tests {
 
     #[test]
     fn test_human_readable_number() {
-        assert_eq!(human_readable_number(1, false), "1B");
-        assert_eq!(human_readable_number(956, false), "956B");
-        assert_eq!(human_readable_number(1004, false), "1004B");
-        assert_eq!(human_readable_number(1024, false), "1.0K");
-        assert_eq!(human_readable_number(1536, false), "1.5K");
-        assert_eq!(human_readable_number(1024 * 512, false), "512K");
-        assert_eq!(human_readable_number(1024 * 1024, false), "1.0M");
-        assert_eq!(
-            human_readable_number(1024 * 1024 * 1024 - 1, false),
-            "1023M"
-        );
-        assert_eq!(human_readable_number(1024 * 1024 * 1024 * 20, false), "20G");
-        assert_eq!(
-            human_readable_number(1024 * 1024 * 1024 * 1024, false),
-            "1.0T"
-        );
+        assert_eq!(human_readable_number(1, ""), "1B");
+        assert_eq!(human_readable_number(956, ""), "956B");
+        assert_eq!(human_readable_number(1004, ""), "1004B");
+        assert_eq!(human_readable_number(1024, ""), "1.0K");
+        assert_eq!(human_readable_number(1536, ""), "1.5K");
+        assert_eq!(human_readable_number(1024 * 512, ""), "512K");
+        assert_eq!(human_readable_number(1024 * 1024, ""), "1.0M");
+        assert_eq!(human_readable_number(1024 * 1024 * 1024 - 1, ""), "1023M");
+        assert_eq!(human_readable_number(1024 * 1024 * 1024 * 20, ""), "20G");
+        assert_eq!(human_readable_number(1024 * 1024 * 1024 * 1024, ""), "1.0T");
+    }
+
+    #[test]
+    fn test_human_readable_number_si() {
+        assert_eq!(human_readable_number(1024 * 100, ""), "100K");
+        assert_eq!(human_readable_number(1024 * 100, "si"), "102K");
+    }
+
+    #[test]
+    fn test_human_readable_number_kb() {
+        let hrn = human_readable_number;
+        assert_eq!(hrn(1023, "b"), "1023B");
+        assert_eq!(hrn(1000 * 1000, "bytes"), "1000000B");
+        assert_eq!(hrn(1023, "kb"), "0K");
+        assert_eq!(hrn(1023, "kib"), "1K");
+        assert_eq!(hrn(1024, "kb"), "1K");
+        assert_eq!(hrn(1024 * 512, "kb"), "512K");
+        assert_eq!(hrn(1024 * 1024, "kb"), "1024K");
+        assert_eq!(hrn(1024 * 1000 * 1000 * 20, "kb"), "20000000K");
+        assert_eq!(hrn(1024 * 1024 * 1000 * 20, "mb"), "20000M");
+        assert_eq!(hrn(1024 * 1024 * 1024 * 20, "gb"), "20G");
     }
 
     #[cfg(test)]
